@@ -15,7 +15,7 @@ use Module::Loaded qw( is_loaded );
 use POSIX          qw( strftime tzset );
 use Ref::Util      qw( is_arrayref );
 
-our $VERSION = '4.5';
+our $VERSION = '4.6';
 
 # Default for Handling Parsing
 our $DateParsing     = 1;
@@ -139,7 +139,7 @@ const my %RE => (
     host            => qr/^\s*([^:\s]+)\s+/,
     cisco_hates_you => qr/^\s*[0-9]*:\s+/,
     program_raw     => qr/^\s*([^\[][^:]+):\s*/,
-    program_name    => qr/^([^\[\(\ ]+)(.*)/,
+    program_name    => qr/^(.[^\[\(\ ]*)(.*)/,
     program_sub     => qr/(?>\(([^\)]+)\))/,
     program_pid     => qr/(?>\[([^\]]+)\])/,
     program_netapp  => qr/(?>\[([^\]]+)\]:\s*)/,
@@ -334,7 +334,7 @@ sub parse_syslog_line {
     $msg{message} = defined $msg{program_raw} ? "$msg{program_raw}: $msg{content}" : $msg{content};
 
     if( $AutoDetectJSON && (my $pos = index($msg{content},'{')) >= 0 ) {
-        unless( $JSONTried && is_loaded('JSON::MaybeXS') ) {
+        unless( $JSONTried || is_loaded('JSON::MaybeXS') ) {
             eval {
                 load JSON::MaybeXS, "decode_json";
                 1;
@@ -492,7 +492,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 4.5
+version 4.6
 
 =head1 SYNOPSIS
 
